@@ -1,6 +1,6 @@
 package Text::ANSI::Printf;
 
-our $VERSION = "2.01";
+our $VERSION = "2.02";
 
 use v5.14;
 use warnings;
@@ -18,10 +18,11 @@ use Text::ANSI::Fold::Util qw(ansi_width);
 sub sprintf {
     my($format, @args) = @_;
     my $conceal = Text::Conceal->new(
-	except => $format,
-	test   => qr/[\e\b\P{ASCII}]/,
-	length => \&ansi_width,
-	max    => int @args,
+	except  => $format,
+	test    => qr/[\e\b\P{ASCII}]/,
+	length  => \&ansi_width,
+	max     => int @args,
+	ordered => 0,
 	);
     $conceal->encode(@args) if $conceal;
     my $s = CORE::sprintf $format, @args;
@@ -46,7 +47,7 @@ Text::ANSI::Printf - printf function for string with ANSI sequence
 
 =head1 VERSION
 
-Version 2.01
+Version 2.02
 
 =head1 SYNOPSIS
 
@@ -67,6 +68,39 @@ capability of handling:
     - Multi-byte wide characters
     - Backspaces
 
+You can give any string including these data as an argument for
+C<printf> and C<sprintf> funcitons.  Each field width is calculated
+based on its visible appearance.
+
+For example,
+
+    printf "| %-5s | %-5s | %-5s |\n", "Red", "Green", "Blue";
+
+this code produces the output like:
+
+    | Red   | Green | Blue  |
+
+However, if the arguments are colored by ANSI sequence,
+
+    printf("| %-5s | %-5s | %-5s |\n",
+           "\e[31mRed\e[m", "\e[32mGreen\e[m", "\e[34mBlue\e[m");
+
+this code produces undsirable result:
+
+    | Red | Green | Blue |
+
+C<ansi_printf> can be used to properly format colored text.
+
+    use Text::ANSI::Printf 'ansi_printf';
+    ansi_printf("| %-5s | %-5s | %-5s |\n",
+           "\e[31mRed\e[m", "\e[32mGreen\e[m", "\e[34mBlue\e[m");
+
+It does not matter if the result is shorter than the original text.
+Next code produces C<[R] [G] [B]> in proper color.
+
+    ansi_printf("[%.1s] [%.1s] [%.1s]\n",
+           "\e[31mRed\e[m", "\e[32mGreen\e[m", "\e[34mBlue\e[m");
+
 =head1 FUNCTIONS
 
 =over 4
@@ -91,17 +125,23 @@ internally.
 
 =head1 SEE ALSO
 
+L<Term::ANSIColor::Concise>,
+L<https://github.com/tecolicom/Term-ANSIColor-Concise>
+
 L<Text::Conceal>,
 L<https://github.com/kaz-utashiro/Text-Conceal>
 
 L<Text::ANSI::Fold::Util>,
-L<https://github.com/kaz-utashiro/Text-ANSI-Fold-Util>
+L<https://github.com/tecolicom/Text-ANSI-Fold-Util>
 
 L<Text::ANSI::Printf>,
-L<https://github.com/kaz-utashiro/Text-ANSI-Printf>
+L<https://github.com/tecolicom/Text-ANSI-Printf>
 
 L<App::ansicolumn>,
-L<https://github.com/kaz-utashiro/App-ansicolumn>
+L<https://github.com/tecolicom/App-ansicolumn>
+
+L<App::ansiecho>,
+L<https://github.com/tecolicom/App-ansiecho>
 
 L<https://en.wikipedia.org/wiki/ANSI_escape_code>
 
@@ -111,7 +151,7 @@ Kazumasa Utashiro
 
 =head1 LICENSE
 
-Copyright 2020 Kazumasa Utashiro.
+Copyright 2020-2023 Kazumasa Utashiro.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
